@@ -85,15 +85,12 @@ class ApplicationService:
             print(line)
 
     def print_message(self):
-        message = [
-            "Embark on your cloud software journey with Spartan determination and simplicity.",
-            "Build your digital empire with unwavering focus and minimalism,",
-            "just like the warriors of ancient Sparta.",
-        ]
-
-        for line in message:
-            print("\n")
-            print(line)
+        message = """
+            Embark on your cloud software journey with Spartan determination and simplicity.,
+            Build your digital empire with unwavering focus and minimalism,,
+            just like the warriors of ancient Sparta.,
+        """
+        print(message)
 
     def print_success_message(self):
         print(f"\nSuccessfully setup the project to {self.project_name} folder.")
@@ -103,6 +100,9 @@ class ApplicationService:
         print(f"---------------")
         print(f"cd {self.project_name}")
         print(f"python -m venv .venv")
+        print(
+            f"source .venv/bin/activate (Linux/Mac) or .venv\\Scripts\\activate (Windows)"
+        )
         print(f"pip install -r requirements.txt")
         print(f"copy the .env.example and name it as .env")
         print(f"spartan migrate init -d sqlite")
